@@ -15,7 +15,10 @@ except ImportError:
 class SearchView(BrowserView):
     def tag(self, obj, scale="thumb" ,css_class='tileImage'):
 	if LEADIMAGE_EXISTS:
-	    context = aq_inner(obj)
+	    try:
+		context = aq_inner(obj)
+	    except:
+		return ''
 	    field = context.getField(IMAGE_FIELD_NAME)
 	    if field is not None:
 		if field.get_size(context) != 0:
